summaryrefslogtreecommitdiffstats
path: root/testsuites/validation/tc-basedefs-no-debug.c
diff options
context:
space:
mode:
Diffstat (limited to 'testsuites/validation/tc-basedefs-no-debug.c')
-rw-r--r--testsuites/validation/tc-basedefs-no-debug.c28
1 files changed, 17 insertions, 11 deletions
diff --git a/testsuites/validation/tc-basedefs-no-debug.c b/testsuites/validation/tc-basedefs-no-debug.c
index df4590a866..b3cfa5dd40 100644
--- a/testsuites/validation/tc-basedefs-no-debug.c
+++ b/testsuites/validation/tc-basedefs-no-debug.c
@@ -3,11 +3,11 @@
/**
* @file
*
- * @ingroup RTEMSTestCaseRtemsBasedefsValBasedefsNoDebug
+ * @ingroup RtemsBasedefsValBasedefsNoDebug
*/
/*
- * Copyright (C) 2022 embedded brains GmbH (http://www.embedded-brains.de)
+ * Copyright (C) 2022 embedded brains GmbH & Co. KG
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
@@ -59,10 +59,10 @@
#include <rtems/test.h>
/**
- * @defgroup RTEMSTestCaseRtemsBasedefsValBasedefsNoDebug \
+ * @defgroup RtemsBasedefsValBasedefsNoDebug \
* spec:/rtems/basedefs/val/basedefs-no-debug
*
- * @ingroup RTEMSTestSuiteTestsuitesValidationNoClock0
+ * @ingroup TestsuitesValidationNoClock0
*
* @brief Tests the basedefs macros where RTEMS_DEBUG is disabled.
*
@@ -72,9 +72,9 @@
*
* - Check that the string is equal to the expected statement.
*
- * - Expand and stringify _Assert_Unreachable().
+ * - Expand RTEMS_FUNCTION_NAME.
*
* - Check that the string is equal to the expected statement.
*
* @{
*/
@@ -95,24 +95,30 @@ static void RtemsBasedefsValBasedefsNoDebug_Action_0( void )
0,
IsEqualIgnoreWhiteSpace(
s,
- "do{__builtin_unreachable();do{}while(0);}while(0)"
+ "__builtin_unreachable()"
)
);
}
/**
- * @brief Expand and stringify _Assert_Unreachable().
+ * @brief Expand RTEMS_FUNCTION_NAME.
*/
static void RtemsBasedefsValBasedefsNoDebug_Action_1( void )
{
const char *s;
- s = RTEMS_XSTRING( _Assert_Unreachable() );
+ s = RTEMS_FUNCTION_NAME;
/*
* Check that the string is equal to the expected statement.
*/
- T_step_true( 1, IsEqualIgnoreWhiteSpace( s, "do{}while(0)" ) );
+ T_step_true(
+ 1,
+ IsEqualIgnoreWhiteSpace(
+ s,
+ "RtemsBasedefsValBasedefsNoDebug_Action_1"
+ )
+ );
}
/**
@@ -72,9 +72,9 @@
*
- * - Check that the string is equal to the expected statement.
+ * - Check that the string is equal to the expected function name.
*
* @{
@@ -95,24 +95,30 @@ static void RtemsBasedefsValBasedefsNoDebug_Action_0( void )
/*
- * Check that the string is equal to the expected statement.
+ * Check that the string is equal to the expected function name.
*/